function _arrayLikeToArray(r, a) {
  (null == a || a > r.length) && (a = r.length);
  for (var e = 0, n = Array(a); e < a; e++) n[e] = r[e];
  return n;
}
function _createForOfIteratorHelperLoose(r, e) {
  var t = "undefined" != typeof Symbol && r[Symbol.iterator] || r["@@iterator"];
  if (t) return (t = t.call(r)).next.bind(t);
  if (Array.isArray(r) || (t = _unsupportedIterableToArray(r)) || e && r && "number" == typeof r.length) {
    t && (r = t);
    var o = 0;
    return function () {
      return o >= r.length ? {
        done: !0
      } : {
        done: !1,
        value: r[o++]
      };
    };
  }
  throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
}
function _extends() {
  return _extends = Object.assign ? Object.assign.bind() : function (n) {
    for (var e = 1; e < arguments.length; e++) {
      var t = arguments[e];
      for (var r in t) ({}).hasOwnProperty.call(t, r) && (n[r] = t[r]);
    }
    return n;
  }, _extends.apply(null, arguments);
}
function _unsupportedIterableToArray(r, a) {
  if (r) {
    if ("string" == typeof r) return _arrayLikeToArray(r, a);
    var t = {}.toString.call(r).slice(8, -1);
    return "Object" === t && r.constructor && (t = r.constructor.name), "Map" === t || "Set" === t ? Array.from(r) : "Arguments" === t || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(t) ? _arrayLikeToArray(r, a) : void 0;
  }
}

function parseBackgroundClasses(className) {
  // Background size
  if (/^bg-(auto|cover|contain)$/.test(className)) {
    return {
      "background-size": className.split("-")[1]
    };
  }
  // Background position
  var positionMap = {
    "bg-bottom": "bottom",
    "bg-top": "top",
    "bg-center": "center",
    "bg-left": "left",
    "bg-left-bottom": "left bottom",
    "bg-left-top": "left top",
    "bg-right": "right",
    "bg-right-bottom": "right bottom",
    "bg-right-top": "right top"
  };
  if (positionMap[className]) {
    return {
      "background-position": positionMap[className]
    };
  }
  // Background attachment
  if (/^bg-(fixed|local|scroll)$/.test(className)) {
    return {
      "background-attachment": className.split("-")[1]
    };
  }
  // Background repeat
  if (/^bg-(no-repeat|repeat|repeat-x|repeat-y|repeat-round|repeat-space)$/.test(className)) {
    return {
      "background-repeat": className.split("-").slice(1).join("-")
    };
  }
  // Background opacity
  var opacityMatch = className.match(/^bg-opacity-(\d+)$/);
  if (opacityMatch) {
    return {
      "--tw-bg-opacity": (parseInt(opacityMatch[1]) / 100).toString()
    };
  }
  // Background clip
  if (/^bg-clip-(border|content|padding|text)$/.test(className)) {
    return {
      "background-clip": className.split("-")[2]
    };
  }
  // Custom background color
  var customColorMatch = className.match(/^bg-\[(#[0-9A-Fa-f]{3,8})\]$/);
  if (customColorMatch) {
    return {
      "background-color": customColorMatch[1]
    };
  }
  var colorMatch = className.match(/^bg-(\w+)(?:-(\d+))?$/);
  if (colorMatch) {
    var color = colorMatch[1];
    var shade = colorMatch[2] || (color === "black" || color === "white" ? null : "500");
    if (colorMap[color]) {
      return {
        "background-color": shade ? colorMap[color][shade] : colorMap[color]
      };
    }
  }
  // Background gradients
  if (/^bg-gradient-to-(t|tr|r|br|b|bl|l|tl)$/.test(className)) {
    var direction = className.split("-").pop();
    var directionMap = {
      t: "to top",
      tr: "to top right",
      r: "to right",
      br: "to bottom right",
      b: "to bottom",
      bl: "to bottom left",
      l: "to left",
      tl: "to top left"
    };
    return {
      "background-image": "linear-gradient(" + directionMap[direction] + ", var(--tw-gradient-stops))"
    };
  }
  // Gradient color stops
  var gradientStopMatch = className.match(/^(from|via|to)-(\w+)(?:-(\d+))?$/);
  if (gradientStopMatch) {
    var position = gradientStopMatch[1],
      _color = gradientStopMatch[2],
      _shade = gradientStopMatch[3];
    if (colorMap[_color]) {
      var _ref;
      var colorValue = _shade ? colorMap[_color][_shade] : colorMap[_color]["500"] || colorMap[_color];
      return _ref = {}, _ref["--tw-gradient-" + position] = colorValue, _ref["--tw-gradient-stops"] = "var(--tw-gradient-from), var(--tw-gradient-to)", _ref;
    }
  }
  // If no match is found
  return null;
}

function parseBorderClasses(className) {
  // Border color
  var borderColorMatch = className.match(/^border-(\[#(?:[0-9a-fA-F]{3}){1,2}\]|transparent|current|black|white|(\w+)-(50|[1-9][0-9]{2}))$/);
  if (borderColorMatch) {
    var colorValue = borderColorMatch[1],
      colorFamily = borderColorMatch[2],
      colorShade = borderColorMatch[3];
    var color;
    if (colorValue.startsWith('[') && colorValue.endsWith(']')) {
      color = colorValue.slice(1, -1);
    } else if (colorValue in colorMap) {
      color = colorMap[colorValue];
    } else if (colorFamily && colorShade) {
      var _colorMap$colorFamily;
      color = (_colorMap$colorFamily = colorMap[colorFamily]) == null ? void 0 : _colorMap$colorFamily[colorShade];
    }
    if (color) {
      return {
        "border-color": color
      };
    }
  }
  // Border style
  var borderStyleMatch = className.match(/^border-(solid|dashed|dotted|double|none)$/);
  if (borderStyleMatch) {
    return {
      "border-style": borderStyleMatch[1]
    };
  }
  // Border width
  var borderWidthMatch = className.match(/^border(-([trbl]))?(-(\d+|(\[[\d.]+[a-z]+\])))?$/);
  if (borderWidthMatch) {
    var _ref;
    var side = borderWidthMatch[2],
      width = borderWidthMatch[4],
      arbitraryWidth = borderWidthMatch[5];
    var prop = side ? "border-" + (side === "r" ? "right" : side === "l" ? "left" : side === "t" ? "top" : "bottom") + "-width" : "border-width";
    var value;
    if (arbitraryWidth) {
      value = arbitraryWidth.slice(1, -1);
    } else if (width) {
      value = parseInt(width) / 4 + "rem";
    } else {
      value = "1px";
    }
    return _ref = {}, _ref[prop] = value, _ref;
  }
  // Standalone "border" class
  if (className === "border") {
    return {
      "border-width": "1px"
    };
  }
  // Border opacity
  var borderOpacityMatch = className.match(/^border-opacity-(\d+|(\[[\d.]+%?\]))$/);
  if (borderOpacityMatch) {
    var opacity = borderOpacityMatch[1],
      arbitraryOpacity = borderOpacityMatch[2];
    var _value = arbitraryOpacity ? arbitraryOpacity.slice(1, -1) : opacity + "%";
    return {
      "--tw-border-opacity": _value
    };
  }
  // Divide
  var divideMatch = className.match(/^divide-(x|y)(-reverse)?(-(\d+|(\[[\d.]+[a-z]+\])))$/);
  if (divideMatch) {
    var _notHidden, _ref2;
    var direction = divideMatch[1],
      reverse = divideMatch[2],
      size = divideMatch[4],
      arbitrarySize = divideMatch[5];
    var _prop = "--tw-divide-" + direction + "-reverse";
    var _value2 = reverse ? "1" : "0";
    var widthProp = "border-" + (direction === "x" ? "left" : "top") + "-width";
    var widthValue;
    if (arbitrarySize) {
      widthValue = arbitrarySize.slice(1, -1);
    } else if (size) {
      widthValue = parseInt(size) / 4 + "rem";
    } else {
      widthValue = "1px";
    }
    return _ref2 = {}, _ref2[_prop] = _value2, _ref2[widthProp] = widthValue, _ref2["& > :not([hidden]) ~ :not([hidden])"] = (_notHidden = {}, _notHidden[_prop] = _value2, _notHidden[widthProp] = widthValue, _notHidden), _ref2;
  }
  // Border collapse
  if (className === "border-collapse") {
    return {
      "border-collapse": "collapse"
    };
  }
  if (className === "border-separate") {
    return {
      "border-collapse": "separate"
    };
  }
  // Rounded corners
  var roundedMatch = className.match(/^rounded(-([trblse]|tl|tr|br|bl))?(-(\w+|(\[[\d.]+[a-z%]+\])))?$/);
  if (roundedMatch) {
    var _side = roundedMatch[2],
      _size = roundedMatch[4],
      _arbitrarySize = roundedMatch[5];
    var props;
    if (_side) {
      switch (_side) {
        case "t":
          props = ["border-top-left-radius", "border-top-right-radius"];
          break;
        case "r":
          props = ["border-top-right-radius", "border-bottom-right-radius"];
          break;
        case "b":
          props = ["border-bottom-left-radius", "border-bottom-right-radius"];
          break;
        case "l":
          props = ["border-top-left-radius", "border-bottom-left-radius"];
          break;
        case "tl":
          props = ["border-top-left-radius"];
          break;
        case "tr":
          props = ["border-top-right-radius"];
          break;
        case "br":
          props = ["border-bottom-right-radius"];
          break;
        case "bl":
          props = ["border-bottom-left-radius"];
          break;
        default:
          props = ["border-radius"];
      }
    } else {
      props = ["border-radius"];
    }
    var _value3;
    if (_arbitrarySize) {
      _value3 = _arbitrarySize.slice(1, -1);
    } else if (_size) {
      switch (_size) {
        case "none":
          _value3 = "0";
          break;
        case "sm":
          _value3 = "0.125rem";
          break;
        case "md":
          _value3 = "0.375rem";
          break;
        case "lg":
          _value3 = "0.5rem";
          break;
        case "xl":
          _value3 = "0.75rem";
          break;
        case "2xl":
          _value3 = "1rem";
          break;
        case "3xl":
          _value3 = "1.5rem";
          break;
        case "full":
          _value3 = "9999px";
          break;
        default:
          _value3 = "0.25rem";
      }
    } else {
      _value3 = "0.25rem";
    }
    var result = {};
    props.forEach(function (prop) {
      result[prop] = _value3;
    });
    return result;
  }
  // If no match is found
  return null;
}

function parseDisplayClasses(className) {
  // Box
  if (/^box-(border|content)$/.test(className)) {
    return {
      "box-sizing": className.split("-")[1]
    };
  }
  // Display
  var displayMap = {
    block: "block",
    hidden: "none",
    inline: "inline",
    "inline-block": "inline-block",
    "inline-flex": "inline-flex",
    "inline-grid": "inline-grid",
    flex: "flex",
    grid: "grid",
    "flow-root": "flow-root"
  };
  if (className in displayMap) {
    return {
      display: displayMap[className]
    };
  }
  // If no match is found
  return null;
}

function parseFlexClasses(className) {
  var flexRegex = {
    flex: /^flex$/,
    flexRow: /^flex-(row|row-reverse|col|col-reverse)$/,
    flexSize: /^flex-(initial|1|auto|none)$/,
    flexWrap: /^flex-(no-wrap|wrap|wrap-reverse)$/,
    items: /^items-(stretch|start|end|center|baseline)$/,
    content: /^content-(start|end|center|between|around|evenly)$/,
    justify: /^justify-(start|end|center|between|around|evenly)$/,
    self: /^self-(auto|start|end|center|stretch|baseline)$/,
    flexGrow: /^flex-grow(-0)?$/,
    flexShrink: /^flex-shrink(-0)?$/,
    order: /^order-(\d+)$/,
    justifyItems: /^justify-items-(auto|start|end|center|stretch)$/,
    justifySelf: /^justify-self-(auto|start|end|center|stretch)$/,
    space: /^space-(x|y)-(\d+|px|reverse)$/
  };
  for (var _i = 0, _Object$entries = Object.entries(flexRegex); _i < _Object$entries.length; _i++) {
    var _Object$entries$_i = _Object$entries[_i],
      key = _Object$entries$_i[0],
      regex = _Object$entries$_i[1];
    var match = className.match(regex);
    if (match) {
      switch (key) {
        case "flex":
          return {
            display: "flex"
          };
        case "flexRow":
          return {
            "flex-direction": match[1] === "col" ? "column" : match[1].replace("col-reverse", "column-reverse")
          };
        case "flexSize":
          return {
            flex: match[1] === "1" ? "1 1 0%" : match[1]
          };
        case "flexWrap":
          return {
            "flex-wrap": match[1].replace("no-wrap", "nowrap")
          };
        case "items":
          return {
            "align-items": match[1]
          };
        case "content":
          return {
            "align-content": match[1]
          };
        case "justify":
          return {
            "justify-content": match[1] === "between" ? "space-between" : match[1]
          };
        case "self":
          return {
            "align-self": match[1]
          };
        case "flexGrow":
          return {
            "flex-grow": match[1] ? "0" : "1"
          };
        case "flexShrink":
          return {
            "flex-shrink": match[1] ? "0" : "1"
          };
        case "order":
          return {
            order: match[1]
          };
        case "justifyItems":
          return {
            "justify-items": match[1]
          };
        case "justifySelf":
          return {
            "justify-self": match[1]
          };
        case "space":
          if (match[2] === "reverse") {
            var _ref;
            return _ref = {}, _ref["margin-" + (match[1] === "x" ? "right" : "bottom")] = "calc(var(--tw-space-" + match[1] + ") * -1)", _ref;
          } else {
            var _ref2;
            var value = match[2] === "px" ? "1px" : parseInt(match[2]) * 0.25 + "rem";
            return _ref2 = {}, _ref2["--tw-space-" + match[1]] = value, _ref2["margin-" + (match[1] === "x" ? "left" : "top")] = "var(--tw-space-" + match[1] + ")", _ref2;
          }
      }
    }
  }
  return null;
}

function parseGridClasses(className) {
  var gridRegexes = [{
    regex: /^col-auto$/,
    style: {
      "grid-column": "auto"
    }
  }, {
    regex: /^col-span-(\d+|full|\[.+?\])$/,
    style: function style(match) {
      return {
        "grid-column": match[1] === "full" ? "1 / -1" : match[1].startsWith('[') && match[1].endsWith(']') ? "span " + match[1].slice(1, -1) + " / span " + match[1].slice(1, -1) : "span " + match[1] + " / span " + match[1]
      };
    }
  }, {
    regex: /^col-start-(\d+|auto|\[.+?\])$/,
    style: function style(match) {
      return {
        "grid-column-start": match[1].startsWith('[') && match[1].endsWith(']') ? match[1].slice(1, -1) : match[1]
      };
    }
  }, {
    regex: /^col-end-(\d+|auto|\[.+?\])$/,
    style: function style(match) {
      return {
        "grid-column-end": match[1].startsWith('[') && match[1].endsWith(']') ? match[1].slice(1, -1) : match[1]
      };
    }
  }, {
    regex: /^gap-(\d+|px|\[.+?\])$/,
    style: function style(match) {
      return {
        "gap": match[1] === "px" ? "1px" : match[1].startsWith('[') && match[1].endsWith(']') ? match[1].slice(1, -1) : parseInt(match[1]) * 0.25 + "rem"
      };
    }
  }, {
    regex: /^row-gap-(\d+|px|\[.+?\])$/,
    style: function style(match) {
      return {
        "row-gap": match[1] === "px" ? "1px" : match[1].startsWith('[') && match[1].endsWith(']') ? match[1].slice(1, -1) : parseInt(match[1]) * 0.25 + "rem"
      };
    }
  }, {
    regex: /^col-gap-(\d+|px|\[.+?\])$/,
    style: function style(match) {
      return {
        "column-gap": match[1] === "px" ? "1px" : match[1].startsWith('[') && match[1].endsWith(']') ? match[1].slice(1, -1) : parseInt(match[1]) * 0.25 + "rem"
      };
    }
  }, {
    regex: /^grid-rows-(\d+|\[.+?\])$/,
    style: function style(match) {
      return {
        "grid-template-rows": match[1].startsWith('[') && match[1].endsWith(']') ? match[1].slice(1, -1) : "repeat(" + match[1] + ", minmax(0, 1fr))"
      };
    }
  }, {
    regex: /^grid-cols-(\d+|\[.+?\])$/,
    style: function style(match) {
      return {
        "grid-template-columns": match[1].startsWith('[') && match[1].endsWith(']') ? match[1].slice(1, -1) : "repeat(" + match[1] + ", minmax(0, 1fr))"
      };
    }
  }, {
    regex: /^grid-flow-(row|col)(-dense)?$/,
    style: function style(match) {
      return {
        "grid-auto-flow": match[2] ? match[1] + " dense" : match[1]
      };
    }
  }, {
    regex: /^row-span-(\d+|full|\[.+?\])$/,
    style: function style(match) {
      return {
        "grid-row": match[1] === "full" ? "1 / -1" : match[1].startsWith('[') && match[1].endsWith(']') ? "span " + match[1].slice(1, -1) + " / span " + match[1].slice(1, -1) : "span " + match[1] + " / span " + match[1]
      };
    }
  }, {
    regex: /^row-start-(auto|\d+|\[.+?\])$/,
    style: function style(match) {
      return {
        "grid-row-start": match[1].startsWith('[') && match[1].endsWith(']') ? match[1].slice(1, -1) : match[1]
      };
    }
  }, {
    regex: /^row-end-(auto|\d+|\[.+?\])$/,
    style: function style(match) {
      return {
        "grid-row-end": match[1].startsWith('[') && match[1].endsWith(']') ? match[1].slice(1, -1) : match[1]
      };
    }
  }, {
    regex: /^auto-(cols|rows)-(auto|fr|max|min|\[.+?\])$/,
    style: function style(match) {
      var _ref;
      return _ref = {}, _ref["grid-auto-" + match[1]] = match[2].startsWith('[') && match[2].endsWith(']') ? match[2].slice(1, -1) : match[2], _ref;
    }
  }, {
    regex: /^gap-(x|y)-(\d+|px|\[.+?\])$/,
    style: function style(match) {
      var _ref2;
      return _ref2 = {}, _ref2["" + (match[1] === "x" ? "column-gap" : "row-gap")] = match[2] === "px" ? "1px" : match[2].startsWith('[') && match[2].endsWith(']') ? match[2].slice(1, -1) : parseInt(match[2]) * 0.25 + "rem", _ref2;
    }
  }, {
    regex: /^place-content-(around|between|center|end|evenly|start|stretch|\[.+?\])$/,
    style: function style(match) {
      return {
        "place-content": match[1].startsWith('[') && match[1].endsWith(']') ? match[1].slice(1, -1) : match[1]
      };
    }
  }, {
    regex: /^place-items-(auto|center|end|start|stretch|\[.+?\])$/,
    style: function style(match) {
      return {
        "place-items": match[1].startsWith('[') && match[1].endsWith(']') ? match[1].slice(1, -1) : match[1]
      };
    }
  }, {
    regex: /^place-self-(auto|center|end|start|stretch|\[.+?\])$/,
    style: function style(match) {
      return {
        "place-self": match[1].startsWith('[') && match[1].endsWith(']') ? match[1].slice(1, -1) : match[1]
      };
    }
  }, {
    regex: /^row-auto$/,
    style: {
      "grid-row": "auto"
    }
  }];
  for (var _i = 0, _gridRegexes = gridRegexes; _i < _gridRegexes.length; _i++) {
    var _gridRegexes$_i = _gridRegexes[_i],
      regex = _gridRegexes$_i.regex,
      style = _gridRegexes$_i.style;
    var match = className.match(regex);
    if (match) {
      return typeof style === "function" ? style(match) : style;
    }
  }
  return null;
}

function parseListClasses(className) {
  var listTypeRegex = /^list-(none|disc|decimal|square)$/;
  var listPositionRegex = /^list-(inside|outside)$/;
  if (listTypeRegex.test(className)) {
    var _className$match;
    var listType = (_className$match = className.match(listTypeRegex)) == null ? void 0 : _className$match[1];
    return listType ? {
      "list-style-type": listType
    } : null;
  }
  if (listPositionRegex.test(className)) {
    var _className$match2;
    var listPosition = (_className$match2 = className.match(listPositionRegex)) == null ? void 0 : _className$match2[1];
    return listPosition ? {
      "list-style-position": listPosition
    } : null;
  }
  // Handle list-* (any valid CSS list-style-type)
  if (className.startsWith("list-") && !["inside", "outside"].includes(className.slice(5))) {
    var _listType = className.slice(5);
    // Check if the listType is a valid CSS list-style-type
    var validListTypes = ["disc", "circle", "square", "decimal", "decimal-leading-zero", "lower-roman", "upper-roman", "lower-greek", "lower-latin", "upper-latin", "armenian", "georgian", "lower-alpha", "upper-alpha", "none"];
    if (validListTypes.includes(_listType)) {
      return {
        "list-style-type": _listType
      };
    }
  }
  return null; // No match found or invalid class
}

function parseMarginClasses(className) {
  var marginValues = {
    "0": "0px",
    "1": "0.25rem",
    "2": "0.5rem",
    "3": "0.75rem",
    "4": "1rem",
    "5": "1.25rem",
    "6": "1.5rem",
    "8": "2rem",
    "10": "2.5rem",
    "11": "2.75rem",
    "12": "3rem",
    "16": "4rem",
    "20": "5rem",
    "24": "6rem",
    "32": "8rem",
    "40": "10rem",
    "48": "12rem",
    "56": "14rem",
    "64": "16rem",
    px: "1px",
    auto: "auto"
  };
  var marginRegex = /^-?(m|mb|mr|mt|ml|mx|my)-(\[.*?\]|0|1|2|3|4|5|6|8|10|11|12|16|20|24|32|40|48|56|64|px|auto)$/;
  var match = className.match(marginRegex);
  if (!match) return null;
  var direction = match[1],
    size = match[2];
  var value;
  if (size.startsWith('[') && size.endsWith(']')) {
    // Handle arbitrary value
    value = size.slice(1, -1);
  } else {
    value = marginValues[size];
  }
  var isNegative = className.startsWith("-");
  var styles = {};
  switch (direction) {
    case "m":
      styles.margin = isNegative ? "-" + value : value;
      break;
    case "mb":
      styles["margin-bottom"] = isNegative ? "-" + value : value;
      break;
    case "mr":
      styles["margin-right"] = isNegative ? "-" + value : value;
      break;
    case "mt":
      styles["margin-top"] = isNegative ? "-" + value : value;
      break;
    case "ml":
      styles["margin-left"] = isNegative ? "-" + value : value;
      break;
    case "mx":
      styles["margin-left"] = isNegative ? "-" + value : value;
      styles["margin-right"] = isNegative ? "-" + value : value;
      break;
    case "my":
      styles["margin-top"] = isNegative ? "-" + value : value;
      styles["margin-bottom"] = isNegative ? "-" + value : value;
      break;
  }
  return styles;
}

function parseOutlineClass(className) {
  var outlineRegex = /^outline-(.+)$/;
  var match = className.match(outlineRegex);
  if (!match) return null;
  var color = match[1];
  switch (color) {
    case "black":
      return {
        outline: "2px solid #000000"
      };
    case "white":
      return {
        outline: "2px solid #ffffff"
      };
    default:
      return null;
  }
}

function parsePaddingClasses(className) {
  var paddingValues = {
    "0": "0px",
    "1": "0.25rem",
    "2": "0.5rem",
    "3": "0.75rem",
    "4": "1rem",
    "5": "1.25rem",
    "6": "1.5rem",
    "8": "2rem",
    "10": "2.5rem",
    "11": "2.75rem",
    "12": "3rem",
    "16": "4rem",
    "20": "5rem",
    "24": "6rem",
    "32": "8rem",
    "40": "10rem",
    "48": "12rem",
    "56": "14rem",
    "64": "16rem",
    px: "1px"
  };
  var paddingRegex = /^(p|pb|pr|pt|pl|px|py)-(\[.*?\]|0|1|2|3|4|5|6|8|10|11|12|16|20|24|32|40|48|56|64|px)$/;
  var match = className.match(paddingRegex);
  if (!match) return null;
  var direction = match[1],
    size = match[2];
  var value;
  if (size.startsWith('[') && size.endsWith(']')) {
    // Handle arbitrary value
    value = size.slice(1, -1);
  } else {
    value = paddingValues[size];
  }
  var styles = {};
  switch (direction) {
    case "p":
      styles.padding = value;
      break;
    case "pb":
      styles["padding-bottom"] = value;
      break;
    case "pr":
      styles["padding-right"] = value;
      break;
    case "pt":
      styles["padding-top"] = value;
      break;
    case "pl":
      styles["padding-left"] = value;
      break;
    case "px":
      styles["padding-left"] = value;
      styles["padding-right"] = value;
      break;
    case "py":
      styles["padding-top"] = value;
      styles["padding-bottom"] = value;
      break;
  }
  return styles;
}

function parsePositioningClasses(className) {
  // Alignment
  if (/^align-(baseline|top|middle|bottom|text-top|text-bottom)$/.test(className)) {
    var alignValue = className.split("-");
    return {
      "vertical-align": alignValue[alignValue.length - 1]
    };
  }
  // Clear
  if (/^clear-(left|right|both|none)$/.test(className)) {
    return {
      clear: className.split("-")[1]
    };
  }
  // Float
  if (/^float-(right|left|none)$/.test(className)) {
    return {
      "float": className.split("-")[1]
    };
  }
  // Inset
  var insetMatch = className.match(/^(-?)(inset-x|inset-y|inset|top|right|bottom|left)(-(.+))?$/);
  if (insetMatch) {
    var sign = insetMatch[1],
      direction = insetMatch[2],
      value = insetMatch[4];
    var cssValue;
    if (value === undefined) {
      cssValue = '0px';
    } else if (value === 'px') {
      cssValue = '1px';
    } else if (value === 'full') {
      cssValue = '100%';
    } else if (value === 'auto') {
      cssValue = 'auto';
    } else if (/^\d+$/.test(value)) {
      cssValue = parseInt(value) * 0.25 + "rem";
    } else {
      // Handle fractional values like '1/2'
      var fractionMatch = value.match(/^(\d+)\/(\d+)$/);
      if (fractionMatch) {
        var numerator = fractionMatch[1],
          denominator = fractionMatch[2];
        cssValue = parseInt(numerator) / parseInt(denominator) * 100 + "%";
      } else {
        cssValue = value;
      }
    }
    // Apply negative sign if present
    if (sign === '-') {
      cssValue = "-" + cssValue;
    }
    var property = direction === "inset" ? ["top", "right", "bottom", "left"] : direction === "inset-x" ? ["left", "right"] : direction === "inset-y" ? ["top", "bottom"] : [direction];
    return Object.fromEntries(property.map(function (prop) {
      return [prop, cssValue];
    }));
  }
  // Object fit and position
  if (/^object-(contain|cover|fill|none|scale-down)$/.test(className)) {
    return {
      "object-fit": className.split("-").slice(1).join("-")
    };
  }
  if (/^object-(bottom|center|left|left-bottom|left-top|right|right-bottom|right-top|top)$/.test(className)) {
    return {
      "object-position": className.split("-").slice(1).join(" ")
    };
  }
  // Z-index
  var zIndexMatch = className.match(/^z-(.+)$/);
  if (zIndexMatch) {
    return {
      "z-index": zIndexMatch[1]
    };
  }
  // Position
  if (/^(static|relative|absolute|fixed|sticky)$/.test(className)) {
    return {
      position: className
    };
  }
  // Negative values
  if (className.startsWith("-")) {
    var positiveClass = className.slice(1);
    var positiveResult = parsePositioningClasses(positiveClass);
    if (positiveResult) {
      return Object.fromEntries(Object.entries(positiveResult).map(function (_ref) {
        var key = _ref[0],
          value = _ref[1];
        return [key, "-" + value];
      }));
    }
  }
  // No match found
  return null;
}

function parseRingClasses(className) {
  // Helper function to get color from colorMap or parse arbitrary value
  function getColorOrArbitrary(value) {
    if (value.startsWith('[') && value.endsWith(']')) {
      return value.slice(1, -1);
    }
    var _value$split = value.split("-"),
      color = _value$split[0],
      shade = _value$split[1];
    if (colorMap[color]) {
      return shade ? colorMap[color][shade] : colorMap[color];
    }
    return null;
  }
  // Ring width
  var ringWidthMatch = className.match(/^ring(-\d+|\[.+\])?$/);
  if (ringWidthMatch) {
    var width = ringWidthMatch[1] ? ringWidthMatch[1].startsWith('[') ? ringWidthMatch[1].slice(1, -1) : parseInt(ringWidthMatch[1].slice(1)) + "px" : '3px';
    return {
      "box-shadow": "0 0 0 " + width + " var(--tw-ring-color)",
      "--tw-ring-offset-shadow": "0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color)",
      "--tw-ring-shadow": "0 0 0 calc(" + width + " + var(--tw-ring-offset-width)) var(--tw-ring-color)"
    };
  }
  // Ring color
  var ringColorMatch = className.match(/^ring-([\w-]+|\[.+\])$/);
  if (ringColorMatch) {
    var color = getColorOrArbitrary(ringColorMatch[1]);
    if (color) {
      return {
        "--tw-ring-color": color
      };
    }
  }
  // Ring inset
  if (className === "ring-inset") {
    return {
      "--tw-ring-inset": "inset"
    };
  }
  // Ring offset width
  var ringOffsetWidthMatch = className.match(/^ring-offset-(\d+|\[.+\])$/);
  if (ringOffsetWidthMatch) {
    var _width = ringOffsetWidthMatch[1].startsWith('[') ? ringOffsetWidthMatch[1].slice(1, -1) : parseInt(ringOffsetWidthMatch[1]) + "px";
    return {
      "--tw-ring-offset-width": _width
    };
  }
  // Ring offset color
  var ringOffsetColorMatch = className.match(/^ring-offset-([\w-]+|\[.+\])$/);
  if (ringOffsetColorMatch) {
    var _color = getColorOrArbitrary(ringOffsetColorMatch[1]);
    if (_color) {
      return {
        "--tw-ring-offset-color": _color
      };
    }
  }
  // Ring opacity
  var ringOpacityMatch = className.match(/^ring-opacity-(\d+|\[.+\])$/);
  if (ringOpacityMatch) {
    var opacity = ringOpacityMatch[1].startsWith('[') ? ringOpacityMatch[1].slice(1, -1) : (parseInt(ringOpacityMatch[1]) / 100).toString();
    return {
      "--tw-ring-opacity": opacity
    };
  }
  return null;
}

function parseScrollClass(className) {
  var overscrollMatch = className.match(/^overscroll-(contain|auto|none)$/);
  var overscrollXMatch = className.match(/^overscroll-x-(contain|auto|none)$/);
  var overscrollYMatch = className.match(/^overscroll-y-(contain|auto|none)$/);
  if (overscrollMatch) {
    return {
      "overscroll-behavior": overscrollMatch[1]
    };
  }
  if (overscrollXMatch) {
    return {
      "overscroll-behavior-x": overscrollXMatch[1]
    };
  }
  if (overscrollYMatch) {
    return {
      "overscroll-behavior-y": overscrollYMatch[1]
    };
  }
  return null; // Return null if no match is found
}

function parseShadowClass(className) {
  var shadowMap = {
    "shadow-xs": "0 0 0 1px rgba(0, 0, 0, 0.05)",
    "shadow-sm": "0 1px 2px 0 rgba(0, 0, 0, 0.05)",
    shadow: "0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06)",
    "shadow-md": "0 4px 6px -1px rgba(0, 0, 0, 0.1), 0 2px 4px -1px rgba(0, 0, 0, 0.06)",
    "shadow-lg": "0 10px 15px -3px rgba(0, 0, 0, 0.1), 0 4px 6px -2px rgba(0, 0, 0, 0.05)",
    "shadow-xl": "0 20px 25px -5px rgba(0, 0, 0, 0.1), 0 10px 10px -5px rgba(0, 0, 0, 0.04)",
    "shadow-2xl": "0 25px 50px -12px rgba(0, 0, 0, 0.25)",
    "shadow-inner": "inset 0 2px 4px 0 rgba(0, 0, 0, 0.06)",
    "shadow-outline": "0 0 0 3px rgba(66, 153, 225, 0.5)",
    "shadow-none": "none"
  };
  var regex = /^shadow(-xs|-sm|-md|-lg|-xl|-2xl|-inner|-outline|-none)?$/;
  var match = className.match(regex);
  if (match) {
    var shadowValue = shadowMap[className];
    return shadowValue ? {
      "box-shadow": shadowValue
    } : null;
  }
  return null;
}

function parseSizeClasses(className) {
  var fractions = {
    "1/2": "50%",
    "1/3": "33.333333%",
    "2/3": "66.666667%",
    "1/4": "25%",
    "2/4": "50%",
    "3/4": "75%",
    "1/5": "20%",
    "2/5": "40%",
    "3/5": "60%",
    "4/5": "80%",
    "1/6": "16.666667%",
    "2/6": "33.333333%",
    "3/6": "50%",
    "4/6": "66.666667%",
    "5/6": "83.333333%",
    "1/12": "8.333333%",
    "2/12": "16.666667%",
    "3/12": "25%",
    "4/12": "33.333333%",
    "5/12": "41.666667%",
    "6/12": "50%",
    "7/12": "58.333333%",
    "8/12": "66.666667%",
    "9/12": "75%",
    "10/12": "83.333333%",
    "11/12": "91.666667%"
  };
  var fixedValues = {
    xs: "20rem",
    sm: "24rem",
    md: "28rem",
    lg: "32rem",
    xl: "36rem",
    "2xl": "42rem",
    "3xl": "48rem",
    "4xl": "56rem",
    "5xl": "64rem",
    "6xl": "72rem",
    "7xl": "80rem",
    full: "100%",
    "screen-sm": "640px",
    "screen-md": "768px",
    "screen-lg": "1024px",
    "screen-xl": "1280px",
    "screen-2xl": "1536px",
    none: "none",
    "0": "0rem",
    max: "max-content",
    min: "min-content",
    prose: "65ch"
  };
  function getSizeValue(value) {
    if (value === "auto") return "auto";
    if (value === "px") return "1px";
    if (value === "full") return "100%";
    if (value === "screen") return "100vh";
    if (fractions[value]) return fractions[value];
    if (fixedValues[value]) return fixedValues[value];
    var numericValue = parseInt(value, 10);
    if (!isNaN(numericValue)) {
      return numericValue * 0.25 + "rem";
    }
    var arbitraryMatch = value.match(/^\[(.*?)\]$/);
    if (arbitraryMatch) {
      return arbitraryMatch[1];
    }
    return value;
  }
  // Height
  var heightMatch = className.match(/^h-(\d+|auto|px|full|screen|1\/2|1\/3|2\/3|1\/4|2\/4|3\/4|1\/5|2\/5|3\/5|4\/5|1\/6|2\/6|3\/6|4\/6|5\/6|1\/12|2\/12|3\/12|4\/12|5\/12|6\/12|7\/12|8\/12|9\/12|10\/12|11\/12|\[.*?\])$/);
  if (heightMatch) {
    var value = heightMatch[1];
    return {
      height: getSizeValue(value)
    };
  }
  // Max Height
  var maxHeightMatch = className.match(/^max-h-(full|screen|px|\d+|1\/2|1\/3|2\/3|1\/4|2\/4|3\/4|1\/5|2\/5|3\/5|4\/5|1\/6|2\/6|3\/6|4\/6|5\/6|1\/12|2\/12|3\/12|4\/12|5\/12|6\/12|7\/12|8\/12|9\/12|10\/12|11\/12|\[.*?\])$/);
  if (maxHeightMatch) {
    var _value = maxHeightMatch[1];
    return {
      "max-height": getSizeValue(_value)
    };
  }
  // Min Height
  var minHeightMatch = className.match(/^min-h-(0|full|screen|\d+|1\/2|1\/3|2\/3|1\/4|2\/4|3\/4|1\/5|2\/5|3\/5|4\/5|1\/6|2\/6|3\/6|4\/6|5\/6|1\/12|2\/12|3\/12|4\/12|5\/12|6\/12|7\/12|8\/12|9\/12|10\/12|11\/12|\[.*?\])$/);
  if (minHeightMatch) {
    var _value2 = minHeightMatch[1];
    return {
      "min-height": getSizeValue(_value2)
    };
  }
  // Width
  var widthMatch = className.match(/^w-(\d+|auto|px|full|screen|1\/2|1\/3|2\/3|1\/4|2\/4|3\/4|1\/5|2\/5|3\/5|4\/5|1\/6|2\/6|3\/6|4\/6|5\/6|1\/12|2\/12|3\/12|4\/12|5\/12|6\/12|7\/12|8\/12|9\/12|10\/12|11\/12|\[.*?\])$/);
  if (widthMatch) {
    var _value3 = widthMatch[1];
    return {
      width: getSizeValue(_value3)
    };
  }
  // Max Width
  var maxWidthMatch = className.match(/^max-w-(xs|sm|md|lg|xl|2xl|3xl|4xl|5xl|6xl|7xl|full|screen-sm|screen-md|screen-lg|screen-xl|screen-2xl|none|0|max|min|prose|\d+|1\/2|1\/3|2\/3|1\/4|2\/4|3\/4|1\/5|2\/5|3\/5|4\/5|1\/6|2\/6|3\/6|4\/6|5\/6|1\/12|2\/12|3\/12|4\/12|5\/12|6\/12|7\/12|8\/12|9\/12|10\/12|11\/12|\[.*?\])$/);
  if (maxWidthMatch) {
    var _value4 = maxWidthMatch[1];
    return {
      "max-width": getSizeValue(_value4)
    };
  }
  // Min Width
  var minWidthMatch = className.match(/^min-w-(0|full|max|min|\d+|1\/2|1\/3|2\/3|1\/4|2\/4|3\/4|1\/5|2\/5|3\/5|4\/5|1\/6|2\/6|3\/6|4\/6|5\/6|1\/12|2\/12|3\/12|4\/12|5\/12|6\/12|7\/12|8\/12|9\/12|10\/12|11\/12|\[.*?\])$/);
  if (minWidthMatch) {
    var _value5 = minWidthMatch[1];
    return {
      "min-width": getSizeValue(_value5)
    };
  }
  return null;
}

function parseSvgClass(className) {
  function getTailwindColor(colorName, shade) {
    if (colorMap[colorName] && typeof colorMap[colorName] === 'object' && colorMap[colorName][shade]) {
      return colorMap[colorName][shade];
    } else if (colorMap[colorName] && typeof colorMap[colorName] === "string") {
      return colorMap[colorName];
    }
    return null;
  }
  // SVG
  if (className === "svg") {
    return {
      display: "inline-block",
      "vertical-align": "middle"
    };
  }
  // Fill current
  if (className === "fill-current") {
    return {
      fill: "currentColor"
    };
  }
  // Stroke current
  if (className === "stroke-current") {
    return {
      stroke: "currentColor"
    };
  }
  // Stroke width
  var strokeWidthMatch = className.match(/^stroke-(\d+)$/);
  if (strokeWidthMatch) {
    var width = parseInt(strokeWidthMatch[1]);
    return {
      "stroke-width": "" + width
    };
  }
  // Stroke color
  var strokeColorMatch = className.match(/^stroke-([a-z]+)-(\d+)$/);
  if (strokeColorMatch) {
    var color = getTailwindColor(strokeColorMatch[1], strokeColorMatch[2]);
    return color ? {
      stroke: color
    } : null;
  }
  // No match found
  return null;
}

function parseTailwindBreakpoint(breakpoint) {
  var standardBreakpoints = {
    'sm': '640px',
    'md': '768px',
    'lg': '1024px',
    'xl': '1280px',
    '2xl': '1536px'
  };
  // Check if it's a standard min-width breakpoint
  if (breakpoint in standardBreakpoints) {
    return {
      type: 'min-width',
      value: standardBreakpoints[breakpoint]
    };
  }
  // Check if it's a standard max-width breakpoint
  var maxStandardMatch = breakpoint.match(/^max-(.+)$/);
  if (maxStandardMatch && maxStandardMatch[1] in standardBreakpoints) {
    return {
      type: 'max-width',
      value: standardBreakpoints[maxStandardMatch[1]]
    };
  }
  // Check for custom min-width breakpoint
  var minWidthMatch = breakpoint.match(/^min-\[(\d+)(px|rem|em)\]$/);
  if (minWidthMatch) {
    return {
      type: 'min-width',
      value: "" + minWidthMatch[1] + minWidthMatch[2]
    };
  }
  // Check for custom max-width breakpoint
  var maxWidthMatch = breakpoint.match(/^max-\[(\d+)(px|rem|em)\]$/);
  if (maxWidthMatch) {
    return {
      type: 'max-width',
      value: "" + maxWidthMatch[1] + maxWidthMatch[2]
    };
  }
  // If no match found, return null or throw an error
  return null;
}

function parseTailwindTableClass(className) {
  var tableClasses = {
    table: {
      display: "table"
    },
    "table-caption": {
      display: "table-caption"
    },
    "table-cell": {
      display: "table-cell"
    },
    "table-column": {
      display: "table-column"
    },
    "table-column-group": {
      display: "table-column-group"
    },
    "table-footer-group": {
      display: "table-footer-group"
    },
    "table-header-group": {
      display: "table-header-group"
    },
    "table-row-group": {
      display: "table-row-group"
    },
    "table-row": {
      display: "table-row"
    },
    "table-auto": {
      "table-layout": "auto"
    },
    "table-fixed": {
      "table-layout": "fixed"
    }
  };
  var regex = new RegExp("^(" + Object.keys(tableClasses).join("|") + ")$");
  var match = className.match(regex);
  if (match) {
    return tableClasses[match[0]];
  }
  return null;
}

function parseTextClass(className) {
  // Text rendering
  if (/^antialiased$/.test(className)) {
    return {
      "-webkit-font-smoothing": "antialiased",
      "-moz-osx-font-smoothing": "grayscale"
    };
  }
  if (/^subpixel-antialiased$/.test(className)) {
    return {
      "-webkit-font-smoothing": "auto",
      "-moz-osx-font-smoothing": "auto"
    };
  }
  // Text opacity
  var textOpacityMatch = className.match(/^text-opacity-(\d+)$/);
  if (textOpacityMatch) {
    return {
      opacity: String(Number(textOpacityMatch[1]) / 100)
    };
  }
  // Word breaking
  if (/^break-normal$/.test(className)) {
    return {
      "word-break": "normal",
      "overflow-wrap": "normal"
    };
  }
  if (/^break-words$/.test(className)) {
    return {
      "overflow-wrap": "break-word"
    };
  }
  if (/^break-all$/.test(className)) {
    return {
      "word-break": "break-all"
    };
  }
  if (/^truncate$/.test(className)) {
    return {
      overflow: "hidden",
      "text-overflow": "ellipsis",
      "white-space": "nowrap"
    };
  }
  // Text transform
  if (/^uppercase$/.test(className)) {
    return {
      "text-transform": "uppercase"
    };
  }
  if (/^lowercase$/.test(className)) {
    return {
      "text-transform": "lowercase"
    };
  }
  if (/^capitalize$/.test(className)) {
    return {
      "text-transform": "capitalize"
    };
  }
  if (/^normal-case$/.test(className)) {
    return {
      "text-transform": "none"
    };
  }
  // Line height
  var lineHeightMap = {
    none: "1",
    tight: "1.25",
    snug: "1.375",
    normal: "1.5",
    relaxed: "1.625",
    loose: "2",
    "3": ".75rem",
    "4": "1rem",
    "5": "1.25rem",
    "6": "1.5rem",
    "7": "1.75rem",
    "8": "2rem",
    "9": "2.25rem",
    "10": "2.5rem"
  };
  var leadingMatch = className.match(/^leading-([\w-]+)$/);
  if (leadingMatch && lineHeightMap[leadingMatch[1]]) {
    return {
      "line-height": lineHeightMap[leadingMatch[1]]
    };
  }
  // Text decoration
  if (/^underline$/.test(className)) {
    return {
      "text-decoration": "underline"
    };
  }
  if (/^line-through$/.test(className)) {
    return {
      "text-decoration": "line-through"
    };
  }
  if (/^no-underline$/.test(className)) {
    return {
      "text-decoration": "none"
    };
  }
  // Font weight
  var fontWeightMap = {
    hairline: "100",
    thin: "200",
    light: "300",
    normal: "400",
    medium: "500",
    semibold: "600",
    bold: "700",
    extrabold: "800",
    black: "900"
  };
  var fontWeightMatch = className.match(/^font-([\w-]+)$/);
  if (fontWeightMatch && fontWeightMap[fontWeightMatch[1]]) {
    return {
      "font-weight": fontWeightMap[fontWeightMatch[1]]
    };
  }
  // Font size
  var fontSizeMap = {
    xs: "0.75rem",
    sm: "0.875rem",
    base: "1rem",
    lg: "1.125rem",
    xl: "1.25rem",
    "2xl": "1.5rem",
    "3xl": "1.875rem",
    "4xl": "2.25rem",
    "5xl": "3rem",
    "6xl": "4rem"
  };
  var fontSizeMatch = className.match(/^text-([\w-]+)$/);
  if (fontSizeMatch && fontSizeMap[fontSizeMatch[1]]) {
    return {
      "font-size": fontSizeMap[fontSizeMatch[1]]
    };
  }
  // Font family
  if (/^font-sans$/.test(className)) {
    return {
      "font-family": 'ui-sans-serif, system-ui, -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, "Helvetica Neue", Arial, "Noto Sans", sans-serif, "Apple Color Emoji", "Segoe UI Emoji", "Segoe UI Symbol", "Noto Color Emoji"'
    };
  }
  if (/^font-serif$/.test(className)) {
    return {
      "font-family": 'ui-serif, Georgia, Cambria, "Times New Roman", Times, serif'
    };
  }
  if (/^font-mono$/.test(className)) {
    return {
      "font-family": 'ui-monospace, SFMono-Regular, Menlo, Monaco, Consolas, "Liberation Mono", "Courier New", monospace'
    };
  }
  // Text alignment
  if (/^text-left$/.test(className)) {
    return {
      "text-align": "left"
    };
  }
  if (/^text-center$/.test(className)) {
    return {
      "text-align": "center"
    };
  }
  if (/^text-right$/.test(className)) {
    return {
      "text-align": "right"
    };
  }
  if (/^text-justify$/.test(className)) {
    return {
      "text-align": "justify"
    };
  }
  // Font style
  if (/^italic$/.test(className)) {
    return {
      "font-style": "italic"
    };
  }
  if (/^not-italic$/.test(className)) {
    return {
      "font-style": "normal"
    };
  }
  // Whitespace
  var whitespaceMap = {
    normal: "normal",
    nowrap: "nowrap",
    pre: "pre",
    "pre-line": "pre-line",
    "pre-wrap": "pre-wrap"
  };
  var whitespaceMatch = className.match(/^whitespace-([\w-]+)$/);
  if (whitespaceMatch && whitespaceMap[whitespaceMatch[1]]) {
    return {
      "white-space": whitespaceMap[whitespaceMatch[1]]
    };
  }
  // Letter spacing
  var trackingMap = {
    tighter: "-0.05em",
    tight: "-0.025em",
    normal: "0",
    wide: "0.025em",
    wider: "0.05em",
    widest: "0.1em"
  };
  var trackingMatch = className.match(/^tracking-([\w-]+)$/);
  if (trackingMatch && trackingMap[trackingMatch[1]]) {
    return {
      "letter-spacing": trackingMap[trackingMatch[1]]
    };
  }
  var textColorMatch = className.match(/^text-([\w]+)(?:-([\d]+))?$/);
  if (textColorMatch) {
    var color = textColorMatch[1];
    var shade = textColorMatch[2] || "500";
    if (colorMap[color]) {
      if (typeof colorMap[color] === "string") {
        return {
          color: colorMap[color]
        };
      } else if (colorMap[color][shade]) {
        return {
          color: colorMap[color][shade]
        };
      }
    }
  }
  var sizeOrColorMatch = className.match(/^text-\[(.*?)\]$/);
  if (sizeOrColorMatch) {
    var value = sizeOrColorMatch[1];
    // Check if the value is a valid color (hex, rgb, hsl, etc.)
    if (/^#([0-9A-Fa-f]{3}){1,2}$/.test(value) || /^rgb\(.*\)$/.test(value) || /^hsl\(.*\)$/.test(value) || /^[a-zA-Z]+$/.test(value)) {
      // Named colors
      return {
        color: value
      };
    } else {
      // If it's not a color, assume it's a font size
      return {
        "font-size": value
      };
    }
  }
  // Add support for arbitrary values
  var arbitraryValueMatch = className.match(/^([a-z-]+)-\[(.*?)\]$/);
  if (arbitraryValueMatch) {
    var property = arbitraryValueMatch[1];
    var _value = arbitraryValueMatch[2];
    switch (property) {
      case "text":
        return {
          color: _value
        };
      case "font-size":
        return {
          "font-size": _value
        };
      case "leading":
        return {
          "line-height": _value
        };
      case "tracking":
        return {
          "letter-spacing": _value
        };
      case "text-opacity":
        return {
          "--tw-text-opacity": _value
        };
      case "font-weight":
        return {
          "font-weight": _value
        };
      // Add more cases as needed for other text-related properties
    }
  }
  return null;
}

function parseTransformClass(className) {
  // Transform
  if (className === "transform") return {
    transform: "translate(0px, 0px) rotate(0deg) skewX(0) skewY(0) scaleX(1) scaleY(1)"
  };
  if (className === "transform-none") return {
    transform: "none"
  };
  if (className === "transform-gpu") return {
    transform: "translate3d(0, 0, 0) rotate(0) skewX(0) skewY(0) scaleX(1) scaleY(1)"
  };
  // Origin
  var originMatch = className.match(/^origin-(center|top|right|bottom|left|top-right|top-left|bottom-right|bottom-left)$/);
  if (originMatch) {
    return {
      "transform-origin": originMatch[1].replace("-", " ")
    };
  }
  // Translate
  var translateMatch = className.match(/^(-?)(translate-[xy])-(.+)$/);
  if (translateMatch) {
    var sign = translateMatch[1],
      axis = translateMatch[2],
      value = translateMatch[3];
    var cssValue = value === "full" ? "100%" : value === "1/2" ? "50%" : value === "px" ? "1px" : value.includes("/") ? parseInt(value.split("/")[0]) / parseInt(value.split("/")[1]) * 100 + "%" : parseInt(value) * 0.25 + "rem";
    cssValue = sign === '-' ? "-" + cssValue : cssValue;
    return {
      transform: axis.split('-')[1] + "(" + cssValue + ")"
    };
  }
  // Scale
  var scaleMatch = className.match(/^scale(-[xy])?-(\d+)$/);
  if (scaleMatch) {
    var _axis = scaleMatch[1],
      _value = scaleMatch[2];
    var _cssValue = parseInt(_value) / 100;
    return _axis ? {
      transform: "scale" + _axis.substring(1).toUpperCase() + "(" + _cssValue + ")"
    } : {
      transform: "scale(" + _cssValue + ")"
    };
  }
  // Rotate
  var rotateMatch = className.match(/^(-?)rotate-(\d+)$/);
  if (rotateMatch) {
    var _sign = rotateMatch[1],
      _value2 = rotateMatch[2];
    var degree = _sign === '-' ? "-" + _value2 : _value2;
    return {
      transform: "rotate(" + degree + "deg)"
    };
  }
  // Skew
  var skewMatch = className.match(/^(-?)(skew-[xy])-(\d+)$/);
  if (skewMatch) {
    var _sign2 = skewMatch[1],
      _axis2 = skewMatch[2],
      _value3 = skewMatch[3];
    var _degree = _sign2 === '-' ? "-" + _value3 : _value3;
    return {
      transform: _axis2 + "(" + _degree + "deg)"
    };
  }
  // If no match is found
  return null;
}

function parseTransitionClass(className) {
  // Animation ease
  var easeMatch = className.match(/^ease-(linear|in|out|in-out)$/);
  if (easeMatch) {
    return {
      "transition-timing-function": easeMatch[1]
    };
  }
  // Duration
  var durationMatch = className.match(/^duration-(\d+)$/);
  if (durationMatch) {
    return {
      "transition-duration": durationMatch[1] + "ms"
    };
  }
  // Delay
  var delayMatch = className.match(/^delay-(\d+)$/);
  if (delayMatch) {
    return {
      "transition-delay": delayMatch[1] + "ms"
    };
  }
  // Transition
  if (className === "transition") {
    return {
      "transition-property": "color, background-color, border-color, text-decoration-color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter",
      "transition-timing-function": "cubic-bezier(0.4, 0, 0.2, 1)",
      "transition-duration": "150ms"
    };
  }
  // Transition specific properties
  var transitionMatch = className.match(/^transition-(all|colors|opacity|shadow|transform)$/);
  if (transitionMatch) {
    var property;
    switch (transitionMatch[1]) {
      case "all":
        property = "all";
        break;
      case "colors":
        property = "color, background-color, border-color, text-decoration-color, fill, stroke";
        break;
      case "opacity":
        property = "opacity";
        break;
      case "shadow":
        property = "box-shadow";
        break;
      case "transform":
        property = "transform";
        break;
      default:
        return null;
    }
    return {
      "transition-property": property,
      "transition-timing-function": "cubic-bezier(0.4, 0, 0.2, 1)",
      "transition-duration": "150ms"
    };
  }
  // If no match is found
  return null;
}

function parseUtilClass(className) {
  // Cursor
  var cursorMatch = className.match(/^cursor-(auto|default|move|pointer|text|wait|not-allowed)$/);
  if (cursorMatch) {
    return {
      cursor: cursorMatch[1]
    };
  }
  // Appearance
  if (className === "appearance-none") {
    return {
      appearance: "none"
    };
  }
  // Placeholder color
  var placeholderColorMatch = className.match(/^placeholder-(transparent|current|black|white|gray|red|orange|yellow|green|teal|blue|indigo|purple|pink)-(\d+)$/);
  if (placeholderColorMatch) {
    var color = placeholderColorMatch[1];
    var shade = placeholderColorMatch[2];
    var colorValue;
    if (color === "transparent") {
      colorValue = "transparent";
    } else if (color === "current") {
      colorValue = "currentColor";
    } else if (color === "black") {
      colorValue = "#000";
    } else if (color === "white") {
      colorValue = "#fff";
    } else {
      // You would need to define the actual color values from Tailwind's theme
      var colors = {
        gray: {
          "100": "#f7fafc",
          "600": "#718096"
        },
        red: {
          "100": "#fff5f5",
          "600": "#e53e3e"
        },
        orange: {
          "100": "#fffaf0",
          "600": "#dd6b20"
        },
        yellow: {
          "100": "#fffff0",
          "600": "#d69e2e"
        },
        green: {
          "100": "#f0fff4",
          "600": "#38a169"
        },
        teal: {
          "100": "#e6fffa",
          "600": "#319795"
        },
        blue: {
          "100": "#ebf8ff",
          "600": "#3182ce"
        },
        indigo: {
          "100": "#ebf4ff",
          "600": "#5a67d8"
        },
        purple: {
          "100": "#faf5ff",
          "600": "#805ad5"
        },
        pink: {
          "100": "#fff5f7",
          "600": "#d53f8c"
        }
      };
      colorValue = colors[color][shade];
    }
    return {
      "::placeholder": {
        color: colorValue
      }
    };
  }
  // Placeholder opacity
  var placeholderOpacityMatch = className.match(/^placeholder-opacity-(\d+)$/);
  if (placeholderOpacityMatch) {
    var opacity = parseInt(placeholderOpacityMatch[1]) / 100;
    return {
      "::placeholder": {
        opacity: opacity
      }
    };
  }
  // Outline
  if (className === "outline-none") {
    return {
      outline: "none"
    };
  }
  // Overflow
  var overflowMatch = className.match(/^overflow-(auto|hidden|visible|scroll|x-auto|y-auto|x-hidden|y-hidden|x-visible|y-visible|x-scroll|y-scroll)$/);
  if (overflowMatch) {
    var value = overflowMatch[1];
    if (value.startsWith("x-") || value.startsWith("y-")) {
      var _ref;
      var _value$split = value.split("-"),
        axis = _value$split[0],
        overflow = _value$split[1];
      return _ref = {}, _ref["overflow-" + axis] = overflow, _ref;
    }
    return {
      overflow: value
    };
  }
  // Scrolling
  if (className === "scrolling-touch") {
    return {
      "-webkit-overflow-scrolling": "touch"
    };
  }
  if (className === "scrolling-auto") {
    return {
      "-webkit-overflow-scrolling": "auto"
    };
  }
  // Pointer events
  if (className === "pointer-events-none") {
    return {
      "pointer-events": "none"
    };
  }
  if (className === "pointer-events-auto") {
    return {
      "pointer-events": "auto"
    };
  }
  // Resize
  var resizeMatch = className.match(/^resize(-none|-y|-x)?$/);
  if (resizeMatch) {
    var _value = resizeMatch[1] ? resizeMatch[1].substring(1) : "both";
    return {
      resize: _value
    };
  }
  // Select
  var selectMatch = className.match(/^select-(none|text|all|auto)$/);
  if (selectMatch) {
    return {
      "user-select": selectMatch[1]
    };
  }
  // Number variants
  if (className === "lining-nums") {
    return {
      "font-variant-numeric": "lining-nums"
    };
  }
  if (className === "oldstyle-nums") {
    return {
      "font-variant-numeric": "oldstyle-nums"
    };
  }
  if (className === "normal-nums") {
    return {
      "font-variant-numeric": "normal"
    };
  }
  if (className === "stacked-fractions") {
    return {
      "font-variant-numeric": "stacked-fractions"
    };
  }
  // Content
  var contentMatch = className.match(/^content-\["(.*)"\]$/);
  if (contentMatch) {
    return {
      "content": "\"" + contentMatch[1] + "\""
    };
  }
  // If no match is found
  return null;
}

function parseVisibilityClasses(className) {
  // Opacity
  var opacityMatch = className.match(/^opacity-(\d+)$/);
  if (opacityMatch) {
    var opacityValue = parseInt(opacityMatch[1]) / 100;
    if (opacityValue >= 0 && opacityValue <= 1) {
      return {
        opacity: opacityValue.toString()
      };
    } else {
      return null;
    }
  }
  // Visibility
  switch (className) {
    case "visible":
      return {
        visibility: "visible"
      };
    case "invisible":
      return {
        visibility: "hidden"
      };
    case "sr-only":
      return {
        position: "absolute",
        width: "1px",
        height: "1px",
        padding: "0",
        margin: "-1px",
        overflow: "hidden",
        clip: "rect(0, 0, 0, 0)",
        whiteSpace: "nowrap",
        borderWidth: "0"
      };
    case "not-sr-only":
      return {
        position: "static",
        width: "auto",
        height: "auto",
        padding: "0",
        margin: "0",
        overflow: "visible",
        clip: "auto",
        whiteSpace: "normal"
      };
  }
  // If no match is found
  return null;
}

var TAILWIND_MODIFIERS = /*#__PURE__*/new Set(["className", "hover", "focus", "focusWithin", "active", "disabled", "firstChild", "lastChild", "evenChild", "empty"]);
var TAILWIND_PSEUDO_ELEMENT = /*#__PURE__*/new Set(["after", "before"]);
var defaultStyles = {
  "flex-direction": "row",
  display: "block",
  "border-style": "solid",
  "border-width": "0"
};
function parseClassString(className) {
  var style = defaultStyles;
  var variantMap = {};
  if (className.trim() === "") {
    return {
      style: style,
      variants: []
    };
  }
  var classes = className.split(" ").filter(function (a) {
    return a !== "";
  });
  for (var _iterator = _createForOfIteratorHelperLoose(classes), _step; !(_step = _iterator()).done;) {
    var _variantMap$key;
    var cls = _step.value;
    var parts = cls.split(":");
    if (parts.length === 1) {
      style = _extends({}, style, parseClass(parts[0]));
      continue;
    }
    var modifiers = parts.slice(0, parts.length - 1);
    var key = modifiers.join(":");
    variantMap[key] = (_variantMap$key = variantMap[key]) != null ? _variantMap$key : {
      style: {}
    };
    var variant = variantMap[key];
    variant.style = _extends({}, variant.style, parseClass(parts[parts.length - 1]));
    for (var _iterator2 = _createForOfIteratorHelperLoose(modifiers), _step2; !(_step2 = _iterator2()).done;) {
      var modifier = _step2.value;
      if (TAILWIND_MODIFIERS.has(modifier)) {
        variant[modifier] = true;
        continue;
      }
      if (TAILWIND_PSEUDO_ELEMENT.has(modifier)) {
        variant.pseudoElement = modifier;
        continue;
      }
      var breakpoint = parseTailwindBreakpoint(modifier);
      if (breakpoint) {
        variant.mediaQuery = variant.mediaQuery || {};
        variant.mediaQuery[breakpoint.type] = breakpoint.value;
      }
    }
  }
  var result = {
    style: style,
    variants: Object.values(variantMap)
  };
  return result;
}
// Background colors
var colorMap = {
  transparent: "transparent",
  current: "currentColor",
  black: "#000",
  white: "#fff",
  gray: {
    "50": "#F9FAFB",
    "100": "#f7fafc",
    "200": "#edf2f7",
    "300": "#e2e8f0",
    "400": "#cbd5e0",
    "500": "#a0aec0",
    "600": "#718096",
    "700": "#4a5568",
    "800": "#2d3748",
    "900": "#1a202c"
  },
  red: {
    "50": "#FEF2F2",
    "100": "#fff5f5",
    "200": "#fed7d7",
    "300": "#feb2b2",
    "400": "#fc8181",
    "500": "#f56565",
    "600": "#e53e3e",
    "700": "#c53030",
    "800": "#9b2c2c",
    "900": "#742a2a"
  },
  orange: {
    "100": "#fffaf0",
    "200": "#feebc8",
    "300": "#fbd38d",
    "400": "#f6ad55",
    "500": "#ed8936",
    "600": "#dd6b20",
    "700": "#c05621",
    "800": "#9c4221",
    "900": "#7b341e"
  },
  yellow: {
    "50": "#FFFBEB",
    "100": "#fffff0",
    "200": "#fefcbf",
    "300": "#faf089",
    "400": "#f6e05e",
    "500": "#ecc94b",
    "600": "#d69e2e",
    "700": "#b7791f",
    "800": "#975a16",
    "900": "#744210"
  },
  green: {
    "50": "#F0FDF4",
    "100": "#f0fff4",
    "200": "#c6f6d5",
    "300": "#9ae6b4",
    "400": "#68d391",
    "500": "#48bb78",
    "600": "#38a169",
    "700": "#2f855a",
    "800": "#276749",
    "900": "#22543d"
  },
  teal: {
    "100": "#e6fffa",
    "200": "#b2f5ea",
    "300": "#81e6d9",
    "400": "#4fd1c5",
    "500": "#38b2ac",
    "600": "#319795",
    "700": "#2c7a7b",
    "800": "#285e61",
    "900": "#234e52"
  },
  blue: {
    "50": "#EFF6FF",
    "100": "#ebf8ff",
    "200": "#bee3f8",
    "300": "#90cdf4",
    "400": "#63b3ed",
    "500": "#4299e1",
    "600": "#3182ce",
    "700": "#2b6cb0",
    "800": "#2c5282",
    "900": "#2a4365"
  },
  indigo: {
    "50": "#EEF2FF",
    "100": "#ebf4ff",
    "200": "#c3dafe",
    "300": "#a3bffa",
    "400": "#7f9cf5",
    "500": "#667eea",
    "600": "#5a67d8",
    "700": "#4c51bf",
    "800": "#434190",
    "900": "#3c366b"
  },
  purple: {
    "50": "#F5F3FF",
    "100": "#faf5ff",
    "200": "#e9d8fd",
    "300": "#d6bcfa",
    "400": "#b794f4",
    "500": "#9f7aea",
    "600": "#805ad5",
    "700": "#6b46c1",
    "800": "#553c9a",
    "900": "#44337a"
  },
  pink: {
    "50": "#FDF2F8",
    "100": "#fff5f7",
    "200": "#fed7e2",
    "300": "#fbb6ce",
    "400": "#f687b3",
    "500": "#ed64a6",
    "600": "#d53f8c",
    "700": "#b83280",
    "800": "#97266d",
    "900": "#702459"
  }
};
var parsers = [parseBackgroundClasses, parseBorderClasses, parseDisplayClasses, parseFlexClasses, parseGridClasses, parseSizeClasses, parseMarginClasses, parsePaddingClasses, parsePositioningClasses, parseListClasses, parseVisibilityClasses, parseRingClasses, parseOutlineClass, parseScrollClass, parseShadowClass, parseSvgClass, parseTailwindTableClass, parseTextClass, parseTransformClass, parseUtilClass, parseTransitionClass];
function parseClass(cls) {
  for (var _iterator3 = _createForOfIteratorHelperLoose(parsers), _step3; !(_step3 = _iterator3()).done;) {
    var parser = _step3.value;
    var style = parser(cls);
    if (style) {
      return style;
    }
  }
  console.error("COULD NOT PARSE ", cls);
  return {};
}

function tailwindToToddle(html) {
  var parser = new DOMParser();
  var htmlDoc = parser.parseFromString(html, 'text/html');
  var nodeTree = {};
  function visitElement(element, id) {
    var children = element.childNodes.length !== 0 ? Array.from(element.childNodes) : element.textContent ? [element.textContent] : [];
    var attrs = Object.fromEntries(Array.from(element.attributes).filter(function (attr) {
      return attr.name !== 'class';
    }).map(function (attr) {
      return [attr.name, {
        type: 'value',
        value: attr.value
      }];
    }));
    var _parseClassString = parseClassString(element.getAttribute('class') || ''),
      style = _parseClassString.style,
      variants = _parseClassString.variants;
    nodeTree[id] = {
      type: 'element',
      tag: element.tagName.toLowerCase(),
      classes: Object.fromEntries(Array.from(element.classList).map(function (name) {
        return [name, {
          formula: undefined
        }];
      })),
      attrs: attrs,
      events: {},
      style: style,
      styleVariables: {},
      variants: variants,
      children: children.map(function (child) {
        var childId = generateId();
        if (child instanceof Text) {
          var _child$textContent;
          var content = ((_child$textContent = child.textContent) != null ? _child$textContent : "").trim();
          if (/^\s*$/.test(content)) {
            return undefined;
          }
          nodeTree[childId] = {
            type: 'text',
            value: {
              type: 'value',
              value: content
            }
          };
        } else if (child instanceof Element) {
          visitElement(child, childId);
        }
        return childId;
      }).filter(function (c) {
        return c !== undefined;
      })
    };
  }
  switch (htmlDoc.children.length) {
    case 0:
      return {
        root: {
          type: 'text',
          value: {
            type: 'value',
            value: htmlDoc.body.textContent || ''
          }
        }
      };
    case 1:
      {
        visitElement(htmlDoc.body.children[0], 'root');
        return nodeTree;
      }
    default:
      {
        var children = htmlDoc.body.childNodes.length !== 0 ? Array.from(htmlDoc.body.childNodes) : htmlDoc.body.textContent ? [htmlDoc.body.textContent] : [];
        nodeTree.root = {
          type: "element",
          tag: "div",
          attrs: {},
          style: {},
          classes: {},
          children: children.map(function (child) {
            var childId = generateId();
            if (child instanceof Text) {
              var _child$textContent2;
              var content = ((_child$textContent2 = child.textContent) != null ? _child$textContent2 : "").trim();
              if (/^\s*$/.test(content)) {
                return undefined;
              }
              nodeTree[childId] = {
                type: 'text',
                value: {
                  type: 'value',
                  value: content
                }
              };
            } else if (child instanceof Element) {
              visitElement(child, childId);
            }
            return childId;
          }).filter(function (c) {
            return c !== undefined;
          }),
          events: {},
          styleVariables: {},
          variants: []
        };
        return nodeTree;
      }
  }
}
function generateId(size) {
  if (size === void 0) {
    size = 21;
  }
  var chars = 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789_-';
  return new Array(size).fill(0).map(function () {
    return chars[Math.round(Math.random() * chars.length)];
  }).join('');
}

export { parseClassString, tailwindToToddle };
//# sourceMappingURL=tailwind-parser.esm.js.map
